Welcome to Django Roles Access documentation — Django Roles Access 0.8 documentation

# Django Roles Access 0.8 documentation

# Welcome to Django Roles Access documentation

Source code at Source code at Github.com:

# Quick Start

Contents:

- Introduction
  - Main features
- Requirements
- Quick start
  - Installation and configuration
  - Access configuration

# Middleware

Contents:

- Using Django roles access middleware
  - Installation
  - Configuration
- Applications type
  - NOT_SECURED
  - PUBLIC
  - SECURED

# Check view access

Contents:

- Check view access
  - Security report format
  - Analysis
  - Method

# Content access tool

Contents:

- Django roles template tag

# Advanced topics

Contents:

- Required views and app name
- Namespaces and View Name
- Django roles access response
  - DJANGO_ROLES_ACCESS_REDIRECT
  - DJANGO_ROLES_ACCESS_FORBIDDEN_MESSAGE

# Examples

Contents:

- Example
  - 1 Create Django project polls app
  - 2 App and views name
  - 3 Start using `django_roles_access`

# Reference

Contents:

- Reference
  - Data Model
  - Decorator
  - Mixin
  - Middleware

# Indices and tables

- Index
- Module Index
- Search Page